==> ogstools-0.2.0rc1.tar.gz: ogstools-0.2.0rc1/README.md <==
![OGS workflow overview](https://ogs.ogs.xyz/tools/ogstools/_static/ogstools.png "Supporting complex workflows - from preprocessing to simulation to postprocessing")

is a:

- python library for streamlined usage of [OpenGeoSys](https://www.opengeosys.org),
- set of interconnected modules for pre- and postprocessing of simulations with [OpenGeoSys](https://www.opengeosys.org),
- valuable resource that includes documentation, Jupyter notebooks, and workflows for guidance and reference.

# Overview

- **Website:** <https://www.opengeosys.org>
- **Documentation:** <https://ogs.ogs.xyz/tools/ogstools>
- **Source code:** <https://gitlab.opengeosys.org/ogs/tools/ogstools>
- **Contributing:** <https://ogs.ogs.xyz/tools/ogstools/development/index.html>
- **Bug reports:** <https://discourse.opengeosys.org>

# Installation

Install the latest version of ogstools:

```bash
pip install ogstools
```

For further details see the [User Guide](https://ogs.ogs.xyz/tools/ogstools/user-guide/index.html).

# Getting started

For first steps, please take a look at our [examples](https://ogs.ogs.xyz/tools/ogstools/auto_examples/index.html).

# Contribution

Please report bugs on [Discourse](https://discourse.opengeosys.org) or fork the repository on our [GitLab](https://gitlab.opengeosys.org/ogs/tools/ogstools) and create a merge request. We also welcome contributions in the form of merge requests and are here to assist in ensuring that the code passes all quality checks. We recommend starting with the [Developer Guide](https://ogs.ogs.xyz/tools/ogstools/development/index.html) as your initial point of reference.

You may also contribute by [donating](https://gitlab.opengeosys.org/ogs/tools/ogstools/-/blob/release-notes/donation.md) your existing code snippets.

# Related projects

- [ogs](https://pypi.org/project/ogs)
- [ogs6py](https://pypi.org/project/ogs6py)
- [VTUInterface](https://pypi.org/project/VTUinterface)

# License

`ogstools` is distributed under the Modified BSD License. See the `LICENSE`-file for the license text.

==> ogstools-0.3.0.tar.gz: ogstools-0.3.0/README.md <==
![OGS workflow overview](https://ogs.ogs.xyz/tools/ogstools/_static/ogstools.png "Supporting complex workflows - from preprocessing to simulation to postprocessing")

is a:

- Python library for streamlined usage of [OpenGeoSys](https://www.opengeosys.org) that aims to enable [OpenGeoSys](https://www.opengeosys.org) users to harness the full potential of Python's extensive ecosystem.
- set of interconnected modules for pre- and postprocessing of simulations with [OpenGeoSys](https://www.opengeosys.org),
- valuable resource that includes documentation, Jupyter notebooks, and workflows for guidance and reference.

# Overview

- **Website:** <https://www.opengeosys.org>
- **Documentation:** <https://ogs.ogs.xyz/tools/ogstools>
- **Source code:** <https://gitlab.opengeosys.org/ogs/tools/ogstools>
- **Contributing:** <https://ogs.ogs.xyz/tools/ogstools/development/index.html>
- **Bug reports:** <https://discourse.opengeosys.org>

# Installation

Install the latest version of ogstools:

```bash
pip install ogstools
```

For further details see the [User Guide](https://ogs.ogs.xyz/tools/ogstools/user-guide/index.html).

# Getting started

For first steps, please take a look at our [examples](https://ogs.ogs.xyz/tools/ogstools/auto_examples/index.html).

# Contribution

Please report bugs on [Discourse](https://discourse.opengeosys.org) or fork the repository on our [GitLab](https://gitlab.opengeosys.org/ogs/tools/ogstools) and create a merge request. We also welcome contributions in the form of merge requests and are here to assist in ensuring that the code passes all quality checks. We recommend starting with the [Developer Guide](https://ogs.ogs.xyz/tools/ogstools/development/index.html) as your initial point of reference.

You may also contribute by [donating](https://gitlab.opengeosys.org/ogs/tools/ogstools/-/blob/main/donation.md) your existing code snippets.

# Motivation

To gain a deeper insight into the rationale behind the development of this Python library, find a comprehensive motivation section available [here](https://gitlab.opengeosys.org/ogs/tools/ogstools/-/blob/main/docs/user-guide/introduction/motivation.md).

# Related projects

- [ogs](https://pypi.org/project/ogs)
- [ogs6py](https://pypi.org/project/ogs6py)
- [VTUInterface](https://pypi.org/project/VTUinterface)

# License

`ogstools` is distributed under the Modified BSD License. See the `LICENSE`-file for the license text.
